@@ -26,7 +26,8 @@ import (
 type TargetType string
 
 const (
-	TargetTypeOnCPU TargetType = "ON_CPU"
+	TargetTypeOnCPU  TargetType = "ON_CPU"
+	TargetTypeOffCPU TargetType = "OFF_CPU"
 )
 
 func ParseTargetType(err error, val string) (TargetType, error) {
@@ -35,6 +36,8 @@ func ParseTargetType(err error, val string) (TargetType, error) {
 	}
 	if TargetType(val) == TargetTypeOnCPU {
 		return TargetTypeOnCPU, nil
+	} else if TargetType(val) == TargetTypeOffCPU {
+		return TargetTypeOffCPU, nil
 	}
 	return "", fmt.Errorf("could not found target type: %s", val)
 }
